@@ -31,6 +31,8 @@ class QAction;
 namespace QStarDict
 {
 
+class DictBrowserSearch;
+
 /**
  * The DictBrowser widget provides view of translations from given dictionary.
  */
@@ -42,7 +44,7 @@ class DictWidget: public QFrame
         /**
          * Construct empty DictWidget.
          */
-        DictWidget(QWidget *parent = 0, Qt::WindowFlags f = 0);
+        DictWidget(QWidget *parent = 0, Qt::WindowFlags f = Qt::Widget);
 
         /**
          * Set source dictionary.
@@ -102,13 +104,13 @@ class DictWidget: public QFrame
         void on_translationView_sourceChanged(const QUrl &name);
         void saveToFile();
         void speak();
-        #ifndef MAEMO
         void print();
-        #endif // MAEMO
+        void handleSearch();
 
     private:
         DictBrowser *m_translationView;
         QToolBar *m_toolBar;
+        DictBrowserSearch *m_search;
 };
 
 }
