@@ -27,6 +27,7 @@
 #include <unistd.h>
 #elif defined(Q_OS_WIN) // Q_OS_UNIX
 #include <windows.h>
+#include <QMessageBox>
 #endif // Q_OS_WIN
 
 #ifdef QSTARDICT_WITH_TRANSLATIONS
@@ -36,28 +37,31 @@
 
 int main(int argc, char *argv[])
 {
+    QStarDict::Application app(argc, argv);
 #ifdef Q_OS_UNIX
     QSettings lockFile(QDir::homePath() + "/.qstardict/qstardict.pid", QSettings::IniFormat);
     QString lastPid = lockFile.value("LastStart/pid").toString();
     if (lastPid.length() && QDir("/proc/" + lastPid).exists() &&
-        lockFile.value("LastStart/time").toDateTime() == QFileInfo("/proc/" + lastPid).created())
+        lockFile.value("LastStart/time").toDateTime() == QFileInfo("/proc/" + lastPid).lastModified())
     {
         qDebug("qstardict: already running");
         return 0;
     }
     lockFile.setValue("LastStart/pid", getpid());
-    lockFile.setValue("LastStart/time", QFileInfo("/proc/" + QString::number(getpid())).created());
+    lockFile.setValue("LastStart/time", QFileInfo("/proc/" + QString::number(getpid())).lastModified());
     lockFile.sync();
 #elif defined(Q_OS_WIN) // Q_OS_UNIX
-    int hMutex = CreateMutex(NULL, true, "qstardict");
-    if (GetLastError == ERROR_ALREADY_EXISTS)
+    HANDLE hMutex = CreateMutex(NULL, true, (LPCTSTR)"qstardict");
+    if (GetLastError() == ERROR_ALREADY_EXISTS)
     {
-        MessageBox(0, "Warning", "QStarDict is already running", MB_ICONWARNING);
+        QMessageBox::information(0, "Warning", "QStarDict is already running");
+        // Strange encoding issue...
+        // MessageBox(0, (LPCWSTR)"Warning", (LPCWSTR)"QStarDict is already running", MB_ICONWARNING);
         return 0;
     }
 #endif // Q_OS_WIN
 
-    QStarDict::Application app(argc, argv);
+
     return app.exec();
 }
 
